gpa(df,tolerance=10^-10,nbiteration=200,scale=TRUE,coord=c(1,2))ktab (i.e. a list of data frames with the same row.names in common)tolerancedf may have non described or non evaluated rows, i.e. rows with missing
values only.
The algorithm used here is the one developed by Commandeur.data(sensopanels)
ktabsenso <- ktab.data.frame(sensopanels, blocks = rep(14,7))
gpa(ktabsenso)Run the code above in your browser using DataLab